summaryrefslogtreecommitdiffstats
path: root/xmlserializer/XmlStringDocSource.h
diff options
context:
space:
mode:
Diffstat (limited to 'xmlserializer/XmlStringDocSource.h')
-rw-r--r--xmlserializer/XmlStringDocSource.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/xmlserializer/XmlStringDocSource.h b/xmlserializer/XmlStringDocSource.h
index d7cde9b..06a0337 100644
--- a/xmlserializer/XmlStringDocSource.h
+++ b/xmlserializer/XmlStringDocSource.h
@@ -33,7 +33,7 @@
#include <string>
/**
* Source class that get an xml document from a string.
* Its base class will check the validity of the document.
*/
class CXmlStringDocSource : public CXmlDocSource
@@ -49,11 +49,11 @@ public:
* @param[in] strNameAttributeName a string containing the name of the root name attribute
* @param[in] bValidateWithSchema a boolean that toggles schema validation
*/
- CXmlStringDocSource(const string& strXmlInput,
- const string& strXmlSchemaFile,
- const string& strRootElementType,
- const string& strRootElementName,
- const string& strNameAttrituteName,
+ CXmlStringDocSource(const std::string& strXmlInput,
+ const std::string& strXmlSchemaFile,
+ const std::string& strRootElementType,
+ const std::string& strRootElementName,
+ const std::string& strNameAttrituteName,
bool bValidateWithSchema);
/**
@@ -33,7 +33,7 @@
#include <string>
/**
- * Source class that get an xml document from a string.
+ * Source class that get an xml document from a std::string.
* Its base class will check the validity of the document.
*/